@@ -66,7 +66,7 @@ def create_asgi_app(
 
     # Static Files
     static_file_routes: list[Route] = []
-    static_files_dir = pathlib.Path(f"./{config.static_files_dir}").absolute()
+    static_files_dir = config.static_files_dir_path.absolute()
     for relative_path in get_static_files(static_files_dir):
         static_file = static_files_dir / relative_path
         if (media_type := mimetypes.guess_type(str(static_file))[0]) is None:
