@@ -1,8 +1,10 @@
+from webcompy.utils._environment import ENVIRONMENT
 from webcompy.utils._serialize import is_json_seriarizable
 from webcompy.utils._text import strip_multiline_text
 
 
 __all__ = [
+    "ENVIRONMENT",
     "is_json_seriarizable",
     "strip_multiline_text",
 ]
