@@ -1,14 +1,11 @@
 from typing import Final, Literal
 
 
-def _get_environment() -> Literal["pyscript", "brython", "other"]:
+def _get_environment() -> Literal["pyscript", "other"]:
     import platform
-    import sys
 
     if "Emscripten" == platform.system():
         return "pyscript"
-    elif "Brython" in sys.version:
-        return "brython"
     else:
         return "other"
 
